@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2025, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2026, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,39 +24,47 @@
  */
 
 /*
+ * UNICODE LICENSE V3
+ *
  * COPYRIGHT AND PERMISSION NOTICE
  *
- * Copyright (c) 1991-2022 Unicode, Inc. All rights reserved.
- * Distributed under the Terms of Use in https://www.unicode.org/copyright.html.
+ * Copyright © 1991-2025 Unicode, Inc.
  *
- * Permission is hereby granted, free of charge, to any person obtaining
- * a copy of the Unicode data files and any associated documentation
- * (the "Data Files") or Unicode software and any associated documentation
- * (the "Software") to deal in the Data Files or Software
- * without restriction, including without limitation the rights to use,
- * copy, modify, merge, publish, distribute, and/or sell copies of
- * the Data Files or Software, and to permit persons to whom the Data Files
- * or Software are furnished to do so, provided that either
- * (a) this copyright and permission notice appear with all copies
- * of the Data Files or Software, or
- * (b) this copyright and permission notice appear in associated
- * Documentation.
+ * NOTICE TO USER: Carefully read the following legal agreement. BY
+ * DOWNLOADING, INSTALLING, COPYING OR OTHERWISE USING DATA FILES, AND/OR
+ * SOFTWARE, YOU UNEQUIVOCALLY ACCEPT, AND AGREE TO BE BOUND BY, ALL OF THE
+ * TERMS AND CONDITIONS OF THIS AGREEMENT. IF YOU DO NOT AGREE, DO NOT
+ * DOWNLOAD, INSTALL, COPY, DISTRIBUTE OR USE THE DATA FILES OR SOFTWARE.
  *
- * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF
- * ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
- * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
- * NONINFRINGEMENT OF THIRD PARTY RIGHTS.
- * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS
- * NOTICE BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL
- * DAMAGES, OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
- * DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER
- * TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
- * PERFORMANCE OF THE DATA FILES OR SOFTWARE.
+ * Permission is hereby granted, free of charge, to any person obtaining a
+ * copy of data files and any associated documentation (the "Data Files") or
+ * software and any associated documentation (the "Software") to deal in the
+ * Data Files or Software without restriction, including without limitation
+ * the rights to use, copy, modify, merge, publish, distribute, and/or sell
+ * copies of the Data Files or Software, and to permit persons to whom the
+ * Data Files or Software are furnished to do so, provided that either (a)
+ * this copyright and permission notice appear with all copies of the Data
+ * Files or Software, or (b) this copyright and permission notice appear in
+ * associated Documentation.
  *
- * Except as contained in this notice, the name of a copyright holder
- * shall not be used in advertising or otherwise to promote the sale,
- * use or other dealings in these Data Files or Software without prior
- * written authorization of the copyright holder.
+ * THE DATA FILES AND SOFTWARE ARE PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
+ * KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
+ * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT OF
+ * THIRD PARTY RIGHTS.
+ *
+ * IN NO EVENT SHALL THE COPYRIGHT HOLDER OR HOLDERS INCLUDED IN THIS NOTICE
+ * BE LIABLE FOR ANY CLAIM, OR ANY SPECIAL INDIRECT OR CONSEQUENTIAL DAMAGES,
+ * OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS,
+ * WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION,
+ * ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THE DATA
+ * FILES OR SOFTWARE.
+ *
+ * Except as contained in this notice, the name of a copyright holder shall
+ * not be used in advertising or otherwise to promote the sale, use or other
+ * dealings in these Data Files or Software without prior written
+ * authorization of the copyright holder.
+ *
+ * SPDX-License-Identifier: Unicode-3.0
  */
 
 package sun.util.resources.cldr.ext;
@@ -67,7 +75,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
     @Override
     protected final Object[][] getContents() {
         final String[] GMT = new String[] {
-               "Amzer keitat Greenwich (AKG)",
+               "amzer keitat Greenwich (AKG)",
                "GMT",
                "",
                "GMT",
@@ -75,11 +83,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "GMT",
             };
         final String[] Apia = new String[] {
-               "eur cʼhoañv Apia",
+               "eur cʼhoañv Samoa",
                "",
-               "eur hañv Apia",
+               "eur hañv Samoa",
                "",
-               "eur Apia",
+               "eur Samoa",
                "",
             };
         final String[] Cook = new String[] {
@@ -115,11 +123,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Hovd = new String[] {
-               "eur cʼhoañv Hovd",
+               "eur cʼhoañv Khovd",
                "",
-               "eur hañv Hovd",
+               "eur hañv Khovd",
                "",
-               "eur Hovd",
+               "eur Khovd",
                "",
             };
         final String[] Iran = new String[] {
@@ -163,7 +171,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Wake = new String[] {
-               "eur Wake Island",
+               "eur Enez Wake",
                "",
                "",
                "",
@@ -251,11 +259,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Samoa = new String[] {
-               "eur cʼhoañv Samoa",
+               "eur cʼhoañv Samoa Amerikan",
                "SST",
-               "eur hañv Samoa",
+               "eur hañv Samoa Amerikan",
                "SST",
-               "eur Samoa",
+               "eur Samoa Amerikan",
                "SST",
             };
         final String[] Syowa = new String[] {
@@ -274,6 +282,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur Tonga",
                "",
             };
+        final String[] Yukon = new String[] {
+               "eur Yukon",
+               "MST",
+               "",
+               "MST",
+               "",
+               "MST",
+            };
         final String[] Alaska = new String[] {
                "eur cʼhoañv Alaska",
                "AKST",
@@ -290,14 +306,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur an Amazon",
                "",
             };
-        final String[] Anadyr = new String[] {
-               "eur cʼhoañv Anadyrʼ",
-               "",
-               "eur hañv Anadyrʼ",
-               "",
-               "eur Anadyrʼ",
-               "",
-            };
         final String[] Azores = new String[] {
                "eur cʼhoañv an Azorez",
                "",
@@ -315,7 +323,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Brunei = new String[] {
-               "eur Brunei Darussalam",
+               "eur Brunei",
                "",
                "",
                "",
@@ -338,6 +346,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Hawaii = new String[] {
+               "eur cʼhoañv Hawaii hag an Aleouted",
+               "HST",
+               "",
+               "HST",
+               "",
+               "HST",
+            };
         final String[] Israel = new String[] {
                "eur cʼhoañv Israel",
                "IST",
@@ -387,11 +403,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Taipei = new String[] {
-               "eur cʼhoañv Taipei",
+               "eur cʼhoañv Taiwan",
                "CST",
-               "eur hañv Taipei",
+               "eur hañv Taiwan",
                "CDT",
-               "eur Taipei",
+               "eur Taiwan",
                "CT",
             };
         final String[] Tuvalu = new String[] {
@@ -411,7 +427,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Wallis = new String[] {
-               "eur Wallis ha Futuna",
+               "eur Wallis-ha-Futuna",
                "",
                "",
                "",
@@ -666,14 +682,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Sakhalin = new String[] {
-               "eur cʼhoañv Sakhalin",
-               "",
-               "eur hañv Sakhalin",
-               "",
-               "eur Sakhalin",
-               "",
-            };
         final String[] Suriname = new String[] {
                "eur Surinam",
                "",
@@ -770,14 +778,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
                "",
             };
-        final String[] Volgograd = new String[] {
-               "eur cʼhoañv Volgograd",
-               "MSK",
-               "eur hañv Volgograd",
-               "MSK",
-               "eur Volgograd",
-               "MSK",
-            };
         final String[] Azerbaijan = new String[] {
                "eur cʼhoañv Azerbaidjan",
                "",
@@ -810,6 +810,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
                "",
             };
+        final String[] Kazakhstan = new String[] {
+               "eur Kazakstan",
+               "",
+               "",
+               "",
+               "",
+               "",
+            };
         final String[] Seychelles = new String[] {
                "eur Sechelez",
                "",
@@ -858,14 +866,6 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur Zeland-Nevez",
                "NZT",
             };
-        final String[] Novosibirsk = new String[] {
-               "eur cʼhoañv Novosibirsk",
-               "",
-               "eur hañv Novosibirsk",
-               "",
-               "eur Novosibirsk",
-               "",
-            };
         final String[] Philippines = new String[] {
                "eur cʼhoañv ar Filipinez",
                "PST",
@@ -923,11 +923,11 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] New_Caledonia = new String[] {
-               "eur cʼhoañv Kaledonia Nevez",
+               "eur cʼhoañv Kaledonia-Nevez",
                "",
-               "eur hañv Kaledonia Nevez",
+               "eur hañv Kaledonia-Nevez",
                "",
-               "eur Kaledonia Nevez",
+               "eur Kaledonia-Nevez",
                "",
             };
         final String[] South_Georgia = new String[] {
@@ -963,12 +963,12 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "EAT",
             };
         final String[] Africa_Western = new String[] {
-               "eur cʼhoañv Afrika ar Cʼhornôg",
-               "WAT",
-               "eur hañv Afrika ar Cʼhornôg",
-               "WAT",
                "eur Afrika ar Cʼhornôg",
                "WAT",
+               "",
+               "WAT",
+               "",
+               "WAT",
             };
         final String[] DumontDUrville = new String[] {
                "eur Dumont-d’Urville",
@@ -1062,9 +1062,9 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "eur cʼhoañv Hawaii hag an Aleouted",
                "HST",
                "eur hañv Hawaii hag an Aleouted",
-               "HST",
+               "HDT",
                "eur Hawaii hag an Aleouted",
-               "HST",
+               "HT",
             };
         final String[] Phoenix_Islands = new String[] {
                "eur Inizi Phoenix",
@@ -1099,7 +1099,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                "",
             };
         final String[] Papua_New_Guinea = new String[] {
-               "eur Papoua-Ginea-Nevez",
+               "eur Papoua Ginea-Nevez",
                "",
                "",
                "",
@@ -1169,7 +1169,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Chicago", America_Central },
             { "America/New_York", America_Eastern },
             { "America/Indianapolis", America_Eastern },
-            { "Pacific/Honolulu", Hawaii_Aleutian },
+            { "Pacific/Honolulu", Hawaii },
             { "America/Anchorage", Alaska },
             { "America/Halifax", Atlantic },
             { "America/Sitka", Alaska },
@@ -1183,7 +1183,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "UTC", ETC_UTC },
             { "GB",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1208,7 +1208,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "ECT", Europe_Central },
             { "EET", Europe_Eastern },
             { "EST", America_Eastern },
-            { "HST", Hawaii_Aleutian },
+            { "HST", Hawaii },
             { "IET", America_Eastern },
             { "IST", India },
             { "JST", Japan },
@@ -1239,7 +1239,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Cuba", Cuba },
             { "Eire",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur cʼhoañv Iwerzhon",
                     "IST",
@@ -1282,7 +1282,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Etc/UTC", ETC_UTC },
             { "GB-Eire",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1315,13 +1315,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Gaza", Europe_Eastern },
             { "Asia/Hovd", Hovd },
             { "Asia/Omsk", Omsk },
+            { "Asia/Oral", Kazakhstan },
             { "Etc/GMT+0", GMT },
             { "Etc/GMT-0", GMT },
             { "Greenwich", GMT },
             { "Kwajalein", Marshall_Islands },
             { "Singapore", Singapore },
             { "US/Alaska", Alaska },
-            { "US/Hawaii", Hawaii_Aleutian },
+            { "US/Hawaii", Hawaii },
             { "Universal",
                 new String[] {
                     "amzer hollvedel kenurzhiet",
@@ -1332,6 +1333,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
                     "UTC",
                 }
             },
+            { "Asia/Aqtau", Kazakhstan },
             { "Asia/Chita", Yakutsk },
             { "Asia/Dacca", Bangladesh },
             { "Asia/Dhaka", Bangladesh },
@@ -1341,13 +1343,16 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
+            { "Asia/Tomsk", Krasnoyarsk },
             { "US/Arizona", America_Mountain },
             { "US/Central", America_Central },
             { "US/Eastern", America_Eastern },
             { "US/Pacific", America_Pacific },
             { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
-            { "Asia/Anadyr", Anadyr },
+            { "Asia/Almaty", Kazakhstan },
+            { "Asia/Aqtobe", Kazakhstan },
+            { "Asia/Atyrau", Kazakhstan },
             { "Asia/Beirut", Europe_Eastern },
             { "Asia/Brunei", Brunei },
             { "Asia/Harbin", China },
@@ -1386,6 +1391,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Baghdad", Arabian },
             { "Asia/Bahrain", Arabian },
             { "Asia/Bangkok", Indochina },
+            { "Asia/Barnaul", Krasnoyarsk },
             { "Asia/Bishkek", Kyrgystan },
             { "Asia/Colombo", India },
             { "Asia/Irkutsk", Irkutsk },
@@ -1400,6 +1406,8 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Thimphu", Bhutan },
             { "Asia/Yakutsk", Yakutsk },
             { "Asia/Yerevan", Armenia },
+            { "Canada/Yukon", Yukon },
+            { "Europe/Kirov", Moscow },
             { "Europe/Malta", Europe_Central },
             { "Europe/Minsk", Moscow },
             { "Europe/Sofia", Europe_Eastern },
@@ -1445,7 +1453,8 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Katmandu", Nepal },
             { "Asia/Khandyga", Yakutsk },
             { "Asia/Makassar", Indonesia_Central },
-            { "Asia/Sakhalin", Sakhalin },
+            { "Asia/Qostanay", Kazakhstan },
+            { "Asia/Sakhalin", Magadan },
             { "Asia/Tashkent", Uzbekistan },
             { "Asia/Tel_Aviv", Israel },
             { "Asia/Ust-Nera", Vladivostok },
@@ -1467,7 +1476,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Berlin", Europe_Central },
             { "Europe/Dublin",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur cʼhoañv Iwerzhon",
                     "IST",
@@ -1477,7 +1486,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             },
             { "Europe/Jersey",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1488,7 +1497,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Lisbon", Europe_Western },
             { "Europe/London",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1513,7 +1522,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Pacific/Nauru", Nauru },
             { "Pacific/Palau", Palau },
             { "Pacific/Samoa", Samoa },
-            { "SystemV/HST10", Hawaii_Aleutian },
+            { "SystemV/HST10", Hawaii },
             { "Africa/Abidjan", GMT },
             { "Africa/Algiers", Europe_Central },
             { "Africa/Conakry", GMT },
@@ -1526,6 +1535,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Cancun", America_Eastern },
             { "America/Cayman", America_Eastern },
             { "America/Cuiaba", Amazon },
+            { "America/Dawson", Yukon },
             { "America/Guyana", Guyana },
             { "America/Havana", Cuba },
             { "America/Inuvik", America_Mountain },
@@ -1542,10 +1552,12 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Asia/Ashkhabad", Turkmenistan },
             { "Asia/Chongqing", China },
             { "Asia/Chungking", China },
+            { "Asia/Famagusta", Europe_Eastern },
             { "Asia/Hong_Kong", Hong_Kong },
             { "Asia/Kathmandu", Nepal },
             { "Asia/Pontianak", Indonesia_Western },
             { "Asia/Pyongyang", Korea },
+            { "Asia/Qyzylorda", Kazakhstan },
             { "Asia/Samarkand", Uzbekistan },
             { "Asia/Singapore", Singapore },
             { "Asia/Vientiane", Indochina },
@@ -1557,7 +1569,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Andorra", Europe_Central },
             { "Europe/Belfast",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1636,7 +1648,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Chisinau", Europe_Eastern },
             { "Europe/Guernsey",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1685,7 +1697,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Antarctica/Troll", GMT },
             { "Asia/Ho_Chi_Minh", Indochina },
             { "Asia/Krasnoyarsk", Krasnoyarsk },
-            { "Asia/Novosibirsk", Novosibirsk },
+            { "Asia/Novosibirsk", Krasnoyarsk },
             { "Asia/Ulaanbaatar", Mongolia },
             { "Asia/Vladivostok", Vladivostok },
             { "Atlantic/Bermuda", Atlantic },
@@ -1702,14 +1714,14 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Europe/Mariehamn", Europe_Eastern },
             { "Europe/Podgorica", Europe_Central },
             { "Europe/Stockholm", Europe_Central },
-            { "Europe/Volgograd", Volgograd },
+            { "Europe/Volgograd", Moscow },
             { "Indian/Christmas", Christmas },
             { "Indian/Kerguelen", French_Southern },
             { "Indian/Mauritius", Mauritius },
             { "Mexico/BajaNorte", America_Pacific },
             { "Pacific/Auckland", New_Zealand },
             { "Pacific/Funafuti", Tuvalu },
-            { "Pacific/Johnston", Hawaii_Aleutian },
+            { "Pacific/Johnston", Hawaii },
             { "Pacific/Pitcairn", Pitcairn },
             { "Africa/Libreville", Africa_Western },
             { "Africa/Lubumbashi", Africa_Central },
@@ -1764,8 +1776,10 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Montserrat", Atlantic },
             { "America/Paramaribo", Suriname },
             { "America/St_Vincent", Atlantic },
+            { "America/Whitehorse", Yukon },
             { "Antarctica/McMurdo", New_Zealand },
             { "Antarctica/Rothera", Rothera },
+            { "Asia/Srednekolymsk", Magadan },
             { "Asia/Ujung_Pandang", Indonesia_Central },
             { "Asia/Yekaterinburg", Yekaterinburg },
             { "Atlantic/Jan_Mayen", Europe_Central },
@@ -1780,7 +1794,7 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "Chile/EasterIsland", Easter },
             { "Europe/Isle_of_Man",
                 new String[] {
-                    "Amzer keitat Greenwich (AKG)",
+                    "amzer keitat Greenwich (AKG)",
                     "GMT",
                     "eur hañv Breizh-Veur",
                     "BST",
@@ -1854,21 +1868,19 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/Indiana/Petersburg", America_Eastern },
             { "timezone.excity.Asia/Chita", "Tchita" },
             { "timezone.excity.Asia/Kabul", "Kaboul" },
-            { "timezone.excity.Asia/Macau", "Macau" },
+            { "timezone.excity.Asia/Macau", "Makao" },
             { "America/Argentina/Catamarca", Argentina },
             { "America/Kentucky/Louisville", America_Eastern },
             { "America/Kentucky/Monticello", America_Eastern },
             { "America/North_Dakota/Beulah", America_Central },
             { "America/North_Dakota/Center", America_Central },
-            { "timezone.excity.Africa/Lome", "Lomé" },
             { "timezone.excity.Asia/Anadyr", "Anadyrʼ" },
             { "timezone.excity.Asia/Beirut", "Bayrut" },
             { "timezone.excity.Asia/Kuwait", "Koweit" },
             { "timezone.excity.Asia/Muscat", "Masqat" },
             { "timezone.excity.Asia/Saigon", "Kêr Hô-Chi-Minh" },
-            { "timezone.excity.Asia/Urumqi", "Ürümqi" },
-            { "timezone.excity.Etc/Unknown", "kêr dianav" },
-            { "timezone.excity.Europe/Kiev", "Kiev" },
+            { "timezone.excity.Etc/Unknown", "Lecʼhiadur dianav" },
+            { "timezone.excity.Europe/Kiev", "Kyyiv" },
             { "timezone.excity.Europe/Rome", "Roma" },
             { "America/Indiana/Indianapolis", America_Eastern },
             { "timezone.excity.Africa/Cairo", "Kaero" },
@@ -1880,9 +1892,8 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.Europe/Paris", "Pariz" },
             { "timezone.excity.Indian/Cocos", "Kokoz" },
             { "timezone.excity.Pacific/Fiji", "Fidji" },
-            { "timezone.excity.America/Belem", "Belém" },
-            { "timezone.excity.America/Thule", "Qânâq" },
-            { "timezone.excity.Asia/Calcutta", "Calcutta" },
+            { "timezone.excity.Pacific/Wake", "Enez Wake" },
+            { "timezone.excity.America/Thule", "Qaanaaq" },
             { "timezone.excity.Asia/Damascus", "Damask" },
             { "timezone.excity.Asia/Tashkent", "Toshkent" },
             { "timezone.excity.Europe/Athens", "Aten" },
@@ -1900,17 +1911,18 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "America/North_Dakota/New_Salem", America_Central },
             { "timezone.excity.Africa/Algiers", "Aljer" },
             { "timezone.excity.Africa/Tripoli", "Tarabulus (Tripoli)" },
-            { "timezone.excity.America/Bogota", "Bogotá" },
             { "timezone.excity.America/Havana", "La Habana" },
             { "timezone.excity.America/Panama", "Panamá" },
             { "timezone.excity.Asia/Jerusalem", "Jeruzalem" },
             { "timezone.excity.Asia/Kamchatka", "Kamtchatka" },
-            { "timezone.excity.Asia/Pyongyang", "Pʼyongyang" },
             { "timezone.excity.Asia/Singapore", "Singapour" },
             { "timezone.excity.Asia/Vientiane", "Viangchan" },
             { "timezone.excity.Europe/Vatican", "Vatikan" },
             { "timezone.excity.Indian/Reunion", "Reünion" },
             { "timezone.excity.Pacific/Easter", "Enez Pask" },
+            { "timezone.excity.Pacific/Midway", "Inizi Midway" },
+            { "timezone.excity.Pacific/Noumea", "Noumea" },
+            { "timezone.excity.Pacific/Wallis", "Wallis-ha-Futuna" },
             { "timezone.excity.Africa/El_Aaiun", "LaʼYoun" },
             { "timezone.excity.Africa/Ndjamena", "NʼDjamena" },
             { "timezone.excity.America/Godthab", "Nuuk (Godthåb)" },
@@ -1935,24 +1947,23 @@ public class TimeZoneNames_br extends TimeZoneNamesBundle {
             { "timezone.excity.Indian/Kerguelen", "Kergelenn" },
             { "timezone.excity.Indian/Mauritius", "Moris" },
             { "timezone.excity.Pacific/Honolulu", "Honolulu" },
+            { "timezone.excity.Pacific/Pitcairn", "Inizi Pitcairn" },
             { "timezone.excity.Africa/Casablanca", "Dar el Beida (Casablanca)" },
-            { "timezone.excity.America/Sao_Paulo", "São Paulo" },
             { "timezone.excity.Europe/Copenhagen", "Kopenhagen" },
             { "timezone.excity.Europe/Luxembourg", "Luksembourg" },
-            { "timezone.excity.Pacific/Galapagos", "Galápagos" },
-            { "timezone.excity.Pacific/Marquesas", "Markiz" },
+            { "timezone.excity.Pacific/Marquesas", "Inizi Markiz" },
             { "timezone.excity.Africa/Addis_Ababa", "Adis Abeba" },
             { "timezone.excity.America/Guadeloupe", "Gwadeloup" },
             { "timezone.excity.America/Martinique", "Martinik" },
-            { "timezone.excity.America/St_Vincent", "Sant Visant" },
+            { "timezone.excity.America/St_Vincent", "Sant-Visant" },
             { "timezone.excity.Asia/Yekaterinburg", "Yekaterinbourg" },
             { "timezone.excity.Atlantic/Reykjavik", "Reykjavík" },
-            { "timezone.excity.Atlantic/St_Helena", "Saint Helena" },
+            { "timezone.excity.Atlantic/St_Helena", "Saint-Helena" },
             { "timezone.excity.Europe/Isle_of_Man", "Manav" },
             { "timezone.excity.America/El_Salvador", "Salvador" },
             { "timezone.excity.America/Mexico_City", "Kêr Vecʼhiko" },
-            { "timezone.excity.Atlantic/Cape_Verde", "Kab Glas" },
-            { "timezone.excity.America/St_Barthelemy", "Saint Barthélemy" },
+            { "timezone.excity.Atlantic/Cape_Verde", "Kab-Glas" },
+            { "timezone.excity.America/St_Barthelemy", "Sant-Bertele" },
             { "timezone.excity.Atlantic/South_Georgia", "Georgia ar Su" },
         };
         return data;
